@@ -1,11 +1,11 @@
 import sys
-WnVFM=object
-WnVFz=staticmethod
-WnVFm=False
-WnVFJ=Exception
-WnVFH=None
-WnVFK=input
-WnVFh=list
+djzLC=object
+djzLV=staticmethod
+djzLM=False
+djzLk=Exception
+djzLa=None
+djzLh=input
+djzLv=list
 import json
 import logging
 import getpass
@@ -13,29 +13,29 @@ from localstack.config import CONFIG_FILE_PATH,load_config_file
 from localstack.constants import API_ENDPOINT
 from localstack.utils.common import to_str,safe_requests,save_file,load_file
 LOG=logging.getLogger(__name__)
-class AuthProvider(WnVFM):
- @WnVFz
+class AuthProvider(djzLC):
+ @djzLV
  def name():
   raise
  def get_or_create_token(self,username,password,headers):
   pass
  def get_user_for_token(self,token):
   pass
- @WnVFz
+ @djzLV
  def providers():
   return{c.name():c for c in AuthProvider.__subclasses__()}
- @WnVFz
- def get(provider,raise_error=WnVFm):
+ @djzLV
+ def get(provider,raise_error=djzLM):
   provider_class=AuthProvider.providers().get(provider)
   if not provider_class:
    msg='Unable to find auth provider class "%s"'%provider
    LOG.warning(msg)
    if raise_error:
-    raise WnVFJ(msg)
-   return WnVFH
+    raise djzLk(msg)
+   return djzLa
   return provider_class()
 class AuthProviderInternal(AuthProvider):
- @WnVFz
+ @djzLV
  def name():
   return 'internal'
  def get_or_create_token(self,username,password,headers):
@@ -46,28 +46,28 @@ class AuthProviderInternal(AuthProvider):
   try:
    result=json.loads(to_str(response.content or '{}'))
    return result['token']
-  except WnVFJ:
+  except djzLk:
    pass
  def read_credentials(self,username):
   print('Please provide your login credentials below')
   if not username:
    sys.stdout.write('Username: ')
    sys.stdout.flush()
-   username=WnVFK()
+   username=djzLh()
   password=getpass.getpass()
   return username,password,{}
  def get_user_for_token(self,token):
-  raise WnVFJ('Not implemented')
-def login(provider,username=WnVFH):
+  raise djzLk('Not implemented')
+def login(provider,username=djzLa):
  auth_provider=AuthProvider.get(provider)
  if not auth_provider:
-  providers=WnVFh(AuthProvider.providers().keys())
-  raise WnVFJ('Unknown provider "%s", should be one of %s'%(provider,providers))
+  providers=djzLv(AuthProvider.providers().keys())
+  raise djzLk('Unknown provider "%s", should be one of %s'%(provider,providers))
  username,password,headers=auth_provider.read_credentials(username)
  print('Verifying credentials ... (this may take a few moments)')
  token=auth_provider.get_or_create_token(username,password,headers)
  if not token:
-  raise WnVFJ('Unable to verify login credentials - please try again')
+  raise djzLk('Unable to verify login credentials - please try again')
  configs=load_config_file()
  configs['login']={'provider':provider,'username':username,'token':token}
  save_file(CONFIG_FILE_PATH,json.dumps(configs))
