@@ -1,12 +1,12 @@
 import os
-bcWhD=True
-bcWhR=Exception
-bcWhi=False
-bcWhY=str
-bcWhU=len
-bcWhK=int
-bcWhP=range
-bcWhN=object
+qMsiF=True
+qMsiz=Exception
+qMsiu=False
+qMsiQ=str
+qMsih=len
+qMsiH=int
+qMsiO=range
+qMsiX=object
 import re
 import sys
 import glob
@@ -24,10 +24,10 @@ ENV_PREPARED={}
 MAX_KEY_CACHE_DURATION_SECS=60*60*24
 LOG=logging.getLogger(__name__)
 ENV_LOCALSTACK_API_KEY='LOCALSTACK_API_KEY'
-def read_api_key(raise_if_missing=bcWhD):
+def read_api_key(raise_if_missing=qMsiF):
  key=(os.environ.get(ENV_LOCALSTACK_API_KEY)or '').strip()
  if not key and raise_if_missing:
-  raise bcWhR('Unable to retrieve API key. Please configure $%s in your environment'%ENV_LOCALSTACK_API_KEY)
+  raise qMsiz('Unable to retrieve API key. Please configure $%s in your environment'%ENV_LOCALSTACK_API_KEY)
  return key
 def fetch_key():
  api_key=read_api_key()
@@ -36,18 +36,18 @@ def fetch_key():
  data={'api_key':api_key,'version':VERSION}
  try:
   logging.getLogger('py.warnings').setLevel(logging.ERROR)
-  result=requests.post('%s/activate'%config.API_URL,json.dumps(data),verify=bcWhi)
+  result=requests.post('%s/activate'%config.API_URL,json.dumps(data),verify=qMsiu)
   if result.status_code>=400:
    content=result.content
    content_type=result.headers.get('Content-Type')
-   raise bcWhR('Received error activating key (code %s): ctype "%s" - %s'%(result.status_code,content_type,content))
+   raise qMsiz('Received error activating key (code %s): ctype "%s" - %s'%(result.status_code,content_type,content))
   key_base64=json.loads(to_str(result.content))['key']
   cache_key_locally(api_key,key_base64)
- except bcWhR as e:
+ except qMsiz as e:
   if log_license_issues():
-   api_key=bcWhY(api_key_configured()or '')
+   api_key=qMsiQ(api_key_configured()or '')
    api_key_prefix=api_key[:3]
-   LOG.warning('Error activating API key "%s..."(%s): %s %s'%(api_key_prefix,bcWhU(api_key),e,traceback.format_exc()))
+   LOG.warning('Error activating API key "%s..."(%s): %s %s'%(api_key_prefix,qMsih(api_key),e,traceback.format_exc()))
   key_base64=load_cached_key(api_key)
  finally:
   logging.getLogger('py.warnings').setLevel(logging.WARNING)
@@ -55,25 +55,25 @@ def fetch_key():
  return decoded_key
 def cache_key_locally(api_key,key_b64):
  configs=localstack_config.load_config_file()
- timestamp=bcWhY(bcWhK(now_utc()))
+ timestamp=qMsiQ(qMsiH(now_utc()))
  key_raw=to_str(base64.b64decode(key_b64))
- for i in bcWhP(bcWhU(timestamp)):
+ for i in qMsiO(qMsih(timestamp)):
   key_raw=str_insert(key_raw,i*2,timestamp[i])
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
- configs['cached_key']={'timestamp':bcWhK(timestamp),'key_hash':md5(api_key),'key':key_b64}
+ configs['cached_key']={'timestamp':qMsiH(timestamp),'key_hash':md5(api_key),'key':key_b64}
  save_file(localstack_config.CONFIG_FILE_PATH,json.dumps(configs))
  return configs
 def load_cached_key(api_key):
  configs=localstack_config.load_config_file()
  cached_key=configs['cached_key']
  if cached_key.get('key_hash')!=md5(api_key):
-  raise bcWhR('Cached key was created for a different API key')
+  raise qMsiz('Cached key was created for a different API key')
  now=now_utc()
  if(now-cached_key['timestamp'])>MAX_KEY_CACHE_DURATION_SECS:
-  raise bcWhR('Cached key expired')
- timestamp=bcWhY(cached_key['timestamp'])
+  raise qMsiz('Cached key expired')
+ timestamp=qMsiQ(cached_key['timestamp'])
  key_raw=to_str(base64.b64decode(cached_key['key']))
- for i in bcWhP(bcWhU(timestamp)):
+ for i in qMsiO(qMsih(timestamp)):
   assert key_raw[i]==timestamp[i]
   key_raw=str_remove(key_raw,i)
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
@@ -112,22 +112,22 @@ def cleanup_environment():
       if os.path.exists(delete_file):
        os.remove(delete_file)
 def prepare_environment():
- class OnClose(bcWhN):
+ class OnClose(qMsiX):
   def __exit__(self,*args,**kwargs):
    if not ENV_PREPARED.get('finalized'):
     cleanup_environment()
-   ENV_PREPARED['finalized']=bcWhD
+   ENV_PREPARED['finalized']=qMsiF
   def __enter__(self,*args,**kwargs):
    pass
  if not ENV_PREPARED.get('finalized'):
   try:
    key=fetch_key()
    if not key:
-    raise bcWhR('Unable to fetch and validate API key from environment')
+    raise qMsiz('Unable to fetch and validate API key from environment')
    if key!='test':
     decrypt_files(key)
     LOG.info('Successfully activated API key')
-  except bcWhR as e:
+  except qMsiz as e:
    if log_license_issues():
     LOG.warning('Unable to activate API key: %s %s'%(e,traceback.format_exc()))
    if config.REQUIRE_PRO:
@@ -137,12 +137,12 @@ def prepare_environment():
 def log_license_issues():
  return api_key_configured()and localstack_config.is_env_true('LOG_LICENSE_ISSUES')
 def api_key_configured():
- return read_api_key(raise_if_missing=bcWhi)
+ return read_api_key(raise_if_missing=qMsiu)
 def get_auth_headers():
  configs=localstack_config.load_config_file()
  login_info=configs.get('login')
  if not login_info:
-  raise bcWhR('Please log in first')
+  raise qMsiz('Please log in first')
  auth_token=login_info['token']
  if not auth_token.startswith('%s '%login_info['provider']):
   auth_token='%s %s'%(login_info['provider'],auth_token)
