@@ -1,20 +1,19 @@
 #!/usr/bin/env python
-yAIEe=None
-yAIEx=True
-yAIEr=Exception
-yAIEB=str
-yAIEM=len
-yAIEs=isinstance
-yAIEW=dict
-yAIEo=hasattr
-yAIEp=int
-yAIEG=False
-yAIEY=bytes
+Dzgre=None
+DzgrJ=True
+Dzgrf=Exception
+Dzgrl=str
+DzgrE=len
+Dzgrv=isinstance
+Dzgro=dict
+DzgrN=hasattr
+DzgrO=int
+Dzgrd=False
+DzgrH=bytes
 import os
 import sys
 import json
 import uuid
-import fcntl
 import socket
 import struct
 import logging
@@ -39,32 +38,32 @@ USED_BIND_ADDRESSES=[]
 MAC_NETWORK_INTERFACE='en0'
 BUCKET_MARKER_LOCAL=(os.environ.get('BUCKET_MARKER_LOCAL')or '').strip()or '__local__'
 class FuncThread(threading.Thread):
- def __init__(self,func,params=yAIEe):
+ def __init__(self,func,params=Dzgre):
   threading.Thread.__init__(self)
-  self.daemon=yAIEx
+  self.daemon=DzgrJ
   self.params=params
   self.func=func
  def run(self):
   try:
    self.func(self.params)
-  except yAIEr as e:
+  except Dzgrf as e:
    log('Error in thread function: %s %s'%(e,traceback.format_exc()))
 class ThreadedHTTPServer(ThreadingMixIn,HTTPServer):
- daemon_threads=yAIEx
+ daemon_threads=DzgrJ
 class RequestHandler(BaseHTTPRequestHandler):
  def do_POST(self):
   self.read_content()
   try:
    result=self.handle_request()
    self.send_response(200)
-  except yAIEr as e:
-   error_string=yAIEB(e)
+  except Dzgrf as e:
+   error_string=Dzgrl(e)
    result=json.dumps({'error':error_string})
    log('Error handling request: %s - %s'%(self.request_json,e))
    self.send_response(500)
-  self.send_header('Content-Length','%s'%yAIEM(result)if result else 0)
+  self.send_header('Content-Length','%s'%DzgrE(result)if result else 0)
   self.end_headers()
-  if yAIEM(result or ''):
+  if DzgrE(result or ''):
    self.wfile.write(to_bytes(result))
  def handle_request(self):
   request=self.request_json
@@ -84,17 +83,17 @@ class RequestHandler(BaseHTTPRequestHandler):
    os._exit(0)
   else:
    result={'error':'Unsupported operation "%s"'%operation}
-  result=json.dumps(result)if yAIEs(result,yAIEW)else result
+  result=json.dumps(result)if Dzgrv(result,Dzgro)else result
   return result
  def read_content(self):
-  if yAIEo(self,'data_bytes'):
+  if DzgrN(self,'data_bytes'):
    return
   content_length=self.headers.get('Content-Length')
-  self.data_bytes=self.rfile.read(yAIEp(content_length))
+  self.data_bytes=self.rfile.read(DzgrO(content_length))
   self.request_json={}
   try:
    self.request_json=json.loads(self.data_bytes)
-  except yAIEr:
+  except Dzgrf:
    pass
 class RequestHandlerRoot(RequestHandler):
  def handle_request(self):
@@ -108,13 +107,13 @@ class RequestHandlerRoot(RequestHandler):
    os._exit(0)
   else:
    result={'error':'Unsupported operation "%s"'%operation}
-  result=json.dumps(result)if yAIEs(result,yAIEW)else result
+  result=json.dumps(result)if Dzgrv(result,Dzgro)else result
   return result
 def s3_download(request):
  bucket=request['bucket']
  key=request['key']
  tmp_dir=os.environ.get('TMPDIR')or tempfile.mkdtemp()
- target_file=os.path.join(tmp_dir,request.get('file_name')or 's3file.%s'%yAIEB(uuid.uuid4()))
+ target_file=os.path.join(tmp_dir,request.get('file_name')or 's3file.%s'%Dzgrl(uuid.uuid4()))
  if not os.path.exists(target_file)or request.get('overwrite'):
   if bucket==BUCKET_MARKER_LOCAL:
    shutil.copy(key,target_file)
@@ -133,14 +132,14 @@ def start_ssh_forward_proxy(options):
   sys.path.append(path)
  from tcp_proxy import server_loop
  port=options.get('port')or get_free_tcp_port()
- host=LOCAL_BIND_ADDRESS_PATTERN.replace('*',yAIEB(yAIEM(USED_BIND_ADDRESSES)+2))
+ host=LOCAL_BIND_ADDRESS_PATTERN.replace('*',Dzgrl(DzgrE(USED_BIND_ADDRESSES)+2))
  create_network_interface_alias(host)
  USED_BIND_ADDRESSES.append(host)
  log('Starting local SSH forward proxy, %s:22 -> localhost:%s'%(host,port))
  options={'bind_port':22,'bind_addr':host,'port':port}
  FuncThread(server_loop,options).start()
  return{'host':host,'forward_port':port}
-def create_network_interface_alias(address,interface=yAIEe):
+def create_network_interface_alias(address,interface=Dzgre):
  sudo_cmd='sudo'
  if is_mac_os():
   interface=interface or MAC_NETWORK_INTERFACE
@@ -157,16 +156,16 @@ def create_network_interface_alias(address,interface=yAIEe):
     assert interface not in['lo']and not iface_addr.startswith('127.')
     run_cmd('{sudo_cmd} ifconfig {iface}:0 {addr} netmask 255.255.255.0 up'.format(sudo_cmd=sudo_cmd,addr=address,iface=interface))
     return
-   except yAIEr as e:
+   except Dzgrf as e:
     log('Unable to create forward proxy on interface %s, address %s: %s'%(interface,address,e))
     pass
- raise yAIEr('Unable to create network interface')
+ raise Dzgrf('Unable to create network interface')
 def run_shell_cmd(command):
  try:
   return{'result':run_cmd(command)}
- except yAIEr as e:
-  error_string=yAIEB(e)
-  if yAIEs(e,subprocess.CalledProcessError):
+ except Dzgrf as e:
+  error_string=Dzgrl(e)
+  if Dzgrv(e,subprocess.CalledProcessError):
    error_string='%s: %s'%(error_string,e.output)
   return{'error':error_string}
 def get_os():
@@ -177,23 +176,24 @@ def get_os():
  return 'windows'
 def run_cmd(cmd):
  log('Running command: %s'%cmd)
- return to_str(subprocess.check_output(cmd,stderr=subprocess.STDOUT,shell=yAIEx))
+ return to_str(subprocess.check_output(cmd,stderr=subprocess.STDOUT,shell=DzgrJ))
 def log(*args):
  print(*args)
  sys.stdout.flush()
 def is_mac_os():
  try:
-  out=to_str(subprocess.check_output('uname -a',shell=yAIEx))
+  out=to_str(subprocess.check_output('uname -a',shell=DzgrJ))
   return 'Darwin' in out
  except subprocess.CalledProcessError:
-  return yAIEG
+  return Dzgrd
 def is_linux():
  try:
-  out=to_str(subprocess.check_output('uname -a',shell=yAIEx))
+  out=to_str(subprocess.check_output('uname -a',shell=DzgrJ))
   return 'Linux' in out
  except subprocess.CalledProcessError:
-  return yAIEG
+  return Dzgrd
 def get_ip_address(ifname):
+ import fcntl
  s=socket.socket(socket.AF_INET,socket.SOCK_DGRAM)
  return socket.inet_ntoa(fcntl.ioctl(s.fileno(),0x8915,struct.pack('256s',to_bytes(ifname[:15])))[20:24])
 def get_free_tcp_port():
@@ -203,29 +203,29 @@ def get_free_tcp_port():
  tcp.close()
  return port
 def to_bytes(obj):
- return obj.encode('utf-8')if yAIEs(obj,yAIEB)else obj
+ return obj.encode('utf-8')if Dzgrv(obj,Dzgrl)else obj
 def to_str(obj):
- return obj.decode('utf-8')if yAIEs(obj,yAIEY)else obj
+ return obj.decode('utf-8')if Dzgrv(obj,DzgrH)else obj
 def start_server(port,handler):
  kill_server(port)
  try:
   log('Starting local daemon server on port %s'%port)
   httpd=ThreadedHTTPServer(('0.0.0.0',port),handler)
   httpd.serve_forever()
- except yAIEr:
+ except Dzgrf:
   log('Local daemon server already running, or port %s not available'%port)
   pass
 def kill_server(port):
  try:
   requests.post('http://localhost:%s'%port,data='{"op":"kill"}')
- except yAIEr:
+ except Dzgrf:
   pass
 def kill_servers():
  kill_server(DEFAULT_PORT_LOCAL_DAEMON)
  kill_server(DEFAULT_PORT_LOCAL_DAEMON_ROOT)
 def main():
  logging.basicConfig()
- daemon_type=sys.argv[1]if yAIEM(sys.argv)>1 else 'main'
+ daemon_type=sys.argv[1]if DzgrE(sys.argv)>1 else 'main'
  os.environ['AWS_ACCESS_KEY_ID']=os.environ.get('AWS_ACCESS_KEY_ID')or 'test'
  os.environ['AWS_SECRET_ACCESS_KEY']=os.environ.get('AWS_SECRET_ACCESS_KEY')or 'test'
  if daemon_type=='main':
@@ -241,12 +241,12 @@ def start_in_background():
  LOG.info('Logging local daemon output to %s'%log_file)
  python_cmd=sys.executable
  cmd='%s %s'%(python_cmd,__file__)
- run(cmd,outfile=log_file,asynchronous=yAIEx)
+ run(cmd,outfile=log_file,asynchronous=DzgrJ)
  LOG.info('Attempting to obtain sudo privileges for local daemon of EC2 API '+'(required to start SSH forward proxy on privileged port 22). '+'You may be asked for your sudo password.')
- run('sudo ls',stdin=yAIEx)
+ run('sudo ls',stdin=DzgrJ)
  def start_root_daemon(*args):
   cmd='sudo %s %s root >> %s'%(python_cmd,__file__,log_file)
-  run(cmd,outfile=log_file,stdin=yAIEx)
+  run(cmd,outfile=log_file,stdin=DzgrJ)
  FuncThread(start_root_daemon).start()
 if __name__=='__main__':
  main()
