@@ -1,16 +1,16 @@
 import os
-LYQIc=object
-LYQIt=None
-LYQID=Exception
-LYQIC=set
-LYQIG=property
-LYQIk=classmethod
-LYQIj=True
-LYQIf=getattr
-LYQIA=type
-LYQIv=isinstance
-LYQIb=list
-LYQIE=False
+CKSyh=object
+CKSyk=None
+CKSyb=Exception
+CKSyd=set
+CKSyx=property
+CKSyY=classmethod
+CKSyD=True
+CKSya=getattr
+CKSyU=type
+CKSyG=isinstance
+CKSyv=list
+CKSyu=False
 import re
 import json
 import logging
@@ -25,17 +25,17 @@ from localstack.utils.common import(load_file,to_str,to_bytes,mkdir,save_file,cp
 from localstack_ext.bootstrap.licensing import get_auth_headers
 LOG=logging.getLogger(__name__)
 PERISTED_FOLDERS=['api_states','dynamodb','kinesis']
-class CloudPodManager(LYQIc):
+class CloudPodManager(CKSyh):
  BACKEND='_none_'
- def __init__(self,pod_name=LYQIt,config=LYQIt):
+ def __init__(self,pod_name=CKSyk,config=CKSyk):
   self.pod_name=pod_name
   self._pod_config=config
  def push(self):
-  raise LYQID('Not implemented')
+  raise CKSyb('Not implemented')
  def pull(self):
-  raise LYQID('Not implemented')
+  raise CKSyb('Not implemented')
  def get_pod_size(self):
-  raise LYQID('Not implemented')
+  raise CKSyb('Not implemented')
  def restart_container(self):
   LOG.info('Restarting LocalStack instance with updated persistence state - this may take some time ...')
   data={'action':'restart'}
@@ -49,20 +49,20 @@ class CloudPodManager(LYQIc):
    response=requests.get(url)
    content=json.loads(to_str(response.content))
    statuses=[v for k,v in content['services'].items()]
-   assert LYQIC(statuses)==LYQIC(['running'])
+   assert CKSyd(statuses)==CKSyd(['running'])
   retry(check_status,sleep=3,retries=10)
- @LYQIG
+ @CKSyx
  def pod_config(self):
   return self._pod_config or PodConfigManager.pod_config(self.pod_name)
- @LYQIk
+ @CKSyY
  def get(cls,pod_name):
   pod_config=PodConfigManager.pod_config(pod_name)
   backend=pod_config.get('backend')
   for clazz in cls.__subclasses__():
    if clazz.BACKEND==backend:
     return clazz(pod_name=pod_name,config=pod_config)
-  raise LYQID('Unable to find Cloud Pod manager implementation type "%s"'%backend)
- @LYQIk
+  raise CKSyb('Unable to find Cloud Pod manager implementation type "%s"'%backend)
+ @CKSyY
  def data_dir(cls):
   if not config.DATA_DIR:
    try:
@@ -74,11 +74,37 @@ class CloudPodManager(LYQIc):
     data_dir_host=[m for m in mounts if m['Destination']==data_dir_env][0]['Source']
     data_dir_host=re.sub(r'^(/host_mnt)?',r'',data_dir_host)
     config.DATA_DIR=data_dir_host
-   except LYQID:
+   except CKSyb:
     LOG.warning('''Unable to determine DATA_DIR from LocalStack Docker container - please make sure $MAIN_CONTAINER_NAME is configured properly''')
   if not config.DATA_DIR:
-   raise LYQID('Working with local cloud pods requires $DATA_DIR configuration')
+   raise CKSyb('Working with local cloud pods requires $DATA_DIR configuration')
   return config.DATA_DIR
+class CloudPodManagerFilesystem(CloudPodManager):
+ BACKEND='file'
+ def push(self):
+  local_folder=self.target_folder()
+  data_dir=self.data_dir()
+  print('Pushing state of cloud pod "%s" to local folder: %s'%(self.pod_name,local_folder))
+  mkdir(local_folder)
+  mkdir(data_dir)
+  cp_r(data_dir,local_folder)
+  print('Done.')
+ def pull(self):
+  local_folder=self.target_folder()
+  data_dir=self.data_dir()
+  if not os.path.exists(local_folder):
+   print('WARN: Local path of cloud pod "%s" does not exist: %s'%(self.pod_name,local_folder))
+   return
+  print('Pulling state of cloud pod "%s" from local folder: %s'%(self.pod_name,local_folder))
+  mkdir(data_dir)
+  cp_r(local_folder,data_dir)
+  self.restart_container()
+ def target_folder(self):
+  local_folder=re.sub(r'^file://','',self.pod_config.get('url',''))
+  return local_folder
+ def get_pod_size(self):
+  target_folder=self.target_folder()
+  return disk_usage(target_folder)
 class CloudPodManagerGit(CloudPodManager):
  BACKEND='git'
  def push(self):
@@ -88,9 +114,9 @@ class CloudPodManagerGit(CloudPodManager):
   remote_location=self.pod_config.get('url')
   try:
    porcelain.pull(repo,remote_location,refspecs=branch)
-  except LYQID as e:
+  except CKSyb as e:
    LOG.info('Unable to pull repo: %s'%e)
-  is_empty_repo=b'HEAD' not in repo or repo.refs.allkeys()==LYQIC([b'HEAD'])
+  is_empty_repo=b'HEAD' not in repo or repo.refs.allkeys()==CKSyd([b'HEAD'])
   if is_empty_repo:
    LOG.debug('Initializing empty repository %s'%self.clone_dir)
    init_file=os.path.join(self.clone_dir,'.init')
@@ -98,7 +124,7 @@ class CloudPodManagerGit(CloudPodManager):
    porcelain.add(repo,init_file)
    porcelain.commit(repo,message='Initial commit')
   if branch not in repo:
-   porcelain.branch_create(repo,branch,force=LYQIj)
+   porcelain.branch_create(repo,branch,force=CKSyD)
   self.switch_branch(branch)
   for folder in PERISTED_FOLDERS:
    LOG.info('Copying persistence folder %s to local git repo %s'%(folder,self.clone_dir))
@@ -119,7 +145,7 @@ class CloudPodManagerGit(CloudPodManager):
   branch=self.pod_config.get('branch')
   remote_ref=b'refs/heads/%s'%to_bytes(branch)
   if remote_ref not in remote_refs:
-   raise LYQID('Unable to find branch "%s" in remote git repo'%branch)
+   raise CKSyb('Unable to find branch "%s" in remote git repo'%branch)
   remote_location=self.pod_config.get('url')
   self.switch_branch(branch)
   branch_ref=b'refs/heads/%s'%to_bytes(branch)
@@ -131,13 +157,13 @@ class CloudPodManagerGit(CloudPodManager):
   for folder in PERISTED_FOLDERS:
    src_folder=os.path.join(self.clone_dir,folder)
    tgt_folder=os.path.join(self.data_dir(),folder)
-   cp_r(src_folder,tgt_folder,rm_dest_on_conflict=LYQIj)
+   cp_r(src_folder,tgt_folder,rm_dest_on_conflict=CKSyD)
   self.restart_container()
  def client(self):
   client,path=get_transport_and_path_from_url(self.pod_config.get('url'))
   return client,path
  def local_repo(self):
-  self.clone_dir=LYQIf(self,'clone_dir',LYQIt)
+  self.clone_dir=CKSya(self,'clone_dir',CKSyk)
   if not self.clone_dir:
    pod_dir_name=re.sub(r'(\s|/)+','',self.pod_name)
    self.clone_dir=os.path.join(config.TMP_FOLDER,'pods',pod_dir_name,'repo')
@@ -157,58 +183,58 @@ class CloudPodManagerGit(CloudPodManager):
  def get_pod_size(self):
   self.local_repo()
   return disk_usage(self.clone_dir)
-class PodConfigManagerMeta(LYQIA):
+class PodConfigManagerMeta(CKSyU):
  def __getattr__(cls,attr):
   def _call(*args,**kwargs):
-   result=LYQIt
+   result=CKSyk
    for manager in cls.CHAIN:
     try:
-     tmp=LYQIf(manager,attr)(*args,**kwargs)
+     tmp=CKSya(manager,attr)(*args,**kwargs)
      if tmp:
       if not result:
        result=tmp
-      elif LYQIv(tmp,LYQIb)and LYQIv(result,LYQIb):
+      elif CKSyG(tmp,CKSyv)and CKSyG(result,CKSyv):
        result.extend(tmp)
-    except LYQID:
+    except CKSyb:
      pass
-   if result is not LYQIt:
+   if result is not CKSyk:
     return result
-   raise LYQID('Unable to run operation "%s" for local or remote configuration'%attr)
+   raise CKSyb('Unable to run operation "%s" for local or remote configuration'%attr)
   return _call
-class PodConfigManager(LYQIc,metaclass=PodConfigManagerMeta):
+class PodConfigManager(CKSyh,metaclass=PodConfigManagerMeta):
  CHAIN=[]
- @LYQIk
+ @CKSyY
  def pod_config(cls,pod_name):
   pods=PodConfigManager.list_pods()
   pod_config=[pod for pod in pods if pod['pod_name']==pod_name]
   if not pod_config:
-   raise LYQID('Unable to find config for pod named "%s"'%pod_name)
+   raise CKSyb('Unable to find config for pod named "%s"'%pod_name)
   return pod_config[0]
-class PodConfigManagerLocal(LYQIc):
+class PodConfigManagerLocal(CKSyh):
  CONFIG_FILE='.localstack.yml'
  def list_pods(self):
-  local_pods=self._load_config(safe=LYQIj).get('pods',{})
+  local_pods=self._load_config(safe=CKSyD).get('pods',{})
   local_pods=[{'pod_name':k,'state':'Local Only',**v}for k,v in local_pods.items()]
-  existing_names=LYQIC([pod['pod_name']for pod in local_pods])
+  existing_names=CKSyd([pod['pod_name']for pod in local_pods])
   result=[pod for pod in local_pods if pod['pod_name']not in existing_names]
   return result
  def store_pod_metadata(self,pod_name,metadata):
   pass
- def _load_config(self,safe=LYQIE):
+ def _load_config(self,safe=CKSyu):
   try:
    return yaml.load(to_str(load_file(self.CONFIG_FILE)))
-  except LYQID:
+  except CKSyb:
    if safe:
     return{}
-   raise LYQID('Unable to find and parse config file "%s"'%self.CONFIG_FILE)
-class PodConfigManagerRemote(LYQIc):
+   raise CKSyb('Unable to find and parse config file "%s"'%self.CONFIG_FILE)
+class PodConfigManagerRemote(CKSyh):
  def list_pods(self):
   result=[]
   auth_headers=get_auth_headers()
   response=safe_requests.get('%s/cloudpods'%API_ENDPOINT,headers=auth_headers)
   content=response.content
   if response.status_code>=400:
-   raise LYQID('Unable to fetch list of pods from API (code %s): %s'%(response.status_code,content))
+   raise CKSyb('Unable to fetch list of pods from API (code %s): %s'%(response.status_code,content))
   remote_pods=json.loads(to_str(content)).get('cloudpods',[])
   remote_pods=[{'state':'Shared',**pod}for pod in remote_pods]
   result.extend(remote_pods)
@@ -219,7 +245,7 @@ class PodConfigManagerRemote(LYQIc):
   response=safe_requests.post('%s/cloudpods'%API_ENDPOINT,json.dumps(metadata),headers=auth_headers)
   content=response.content
   if response.status_code>=400:
-   raise LYQID('Unable to store pod metadata in API (code %s): %s'%(response.status_code,content))
+   raise CKSyb('Unable to store pod metadata in API (code %s): %s'%(response.status_code,content))
   return json.loads(to_str(content))
 PodConfigManager.CHAIN.append(PodConfigManagerLocal())
 PodConfigManager.CHAIN.append(PodConfigManagerRemote())
@@ -231,7 +257,7 @@ def push_state(pod_name,args):
  backend.push()
 def pull_state(pod_name,args):
  if not pod_name:
-  raise LYQID('Need to specify a pod name')
+  raise CKSyb('Need to specify a pod name')
  backend=CloudPodManager.get(pod_name=pod_name)
  backend.pull()
 def list_pods(args):
