@@ -7,35 +7,6 @@ from localstack import constants as localstack_constants
 
 FALSE_STRINGS = localstack_constants.FALSE_STRINGS
 
-# api server config
-API_PATH = '/v1'
-API_PORT_LOCAL = 8183
-API_URL = localstack_constants.API_ENDPOINT
-
-# api endpoints
-API_PATH_USER = '%s/user' % API_PATH
-API_PATH_ORGANIZATIONS = '%s/organizations' % API_PATH
-API_PATH_SIGNIN = '%s/signin' % API_PATH_USER
-API_PATH_SIGNUP = '%s/signup' % API_PATH_USER
-API_PATH_RECOVER = '%s/recover' % API_PATH_USER
-API_PATH_RESEND = '%s/resend' % API_PATH_USER
-API_PATH_ACTIVATE = '%s/activate' % API_PATH_USER
-API_PATH_UNSUBSCRIBE = '%s/unsubscribe' % API_PATH_USER
-API_PATH_KEY_ACTIVATE = '%s/activate' % API_PATH
-API_PATH_CARDS = '%s/cards' % API_PATH_USER
-API_PATH_PLANS = '%s/plans' % API_PATH
-API_PATH_FEEDBACKS = '%s/feedbacks' % API_PATH
-API_PATH_SUBSCRIPTIONS = '%s/subscriptions' % API_PATH_PLANS
-API_PATH_INVOICES = '%s/invoices' % API_PATH_PLANS
-API_PATH_CLOUDPODS = '%s/cloudpods' % API_PATH
-API_PATH_EVENTS = '%s/events' % API_PATH
-API_PATH_STATS = '%s/stats' % API_PATH_EVENTS
-API_PATH_GITHUB = '%s/github' % API_PATH
-API_PATH_CONFIG = '%s/config' % API_PATH
-API_PATH_CI = '%s/ci' % API_PATH
-API_PATH_ADMIN = '%s/admin' % API_PATH
-API_PATH_STRIPE_WEBHOOK = '%s/webhooks/stripe' % API_PATH
-
 ROOT_FOLDER = os.path.realpath(os.path.join(os.path.dirname(os.path.realpath(__file__)), '..'))
 
 PROTECTED_FOLDERS = ('services', 'utils')
