@@ -1,11 +1,11 @@
 import os
-TvUlm=Exception
-TvUld=any
-TvUlc=str
-TvUlW=None
-TvUlx=False
-TvUlK=bool
-TvUlt=True
+knpFa=Exception
+knpFI=any
+knpFE=str
+knpFy=None
+knpFU=False
+knpFY=bool
+knpFS=True
 import logging
 from localstack import config as localstack_config
 from localstack.utils import common
@@ -29,14 +29,14 @@ def register_localstack_plugins():
   try:
    from localstack_ext.services import dns_server
    dns_server.setup_network_configuration()
-  except TvUlm:
+  except knpFa:
    return
   if is_infra_process:
    load_plugin_files()
   try:
    if is_api_key_configured and not is_infra_process and is_api_enabled('ec2'):
     local_daemon.start_in_background()
-  except TvUlm as e:
+  except knpFa as e:
    LOG.warning('Unable to start local daemon process: %s'%e)
   if is_api_key_configured:
    if os.environ.get('EDGE_PORT')and not localstack_config.EDGE_PORT_HTTP:
@@ -67,7 +67,7 @@ def register_localstack_plugins():
    docker_flags+=['-p {a}:{p}:{p}'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
   if not common.is_port_open(dns_server.DNS_PORT,protocols='udp'):
    docker_flags+=['-p {a}:{p}:{p}/udp'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
- if TvUld([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
+ if knpFI([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
   docker_flags+=['-p {start}-{end}:{start}-{end}'.format(start=config_ext.SERVICE_INSTANCES_PORTS_START,end=config_ext.SERVICE_INSTANCES_PORTS_END)]
  if is_api_enabled('eks'):
   kube_config=os.path.expanduser('~/.kube/config')
@@ -91,6 +91,7 @@ def load_plugin_files():
   from localstack_ext.services.apigateway import apigateway_extended
   from localstack_ext.services.athena import athena_starter
   from localstack_ext.services.awslambda import lambda_extended
+  from localstack_ext.services.backup import backup_starter
   from localstack_ext.services.batch import batch_starter,batch_listener
   from localstack_ext.services.cloudformation import cloudformation_extended
   from localstack_ext.services.cloudfront import cloudfront_starter
@@ -144,6 +145,7 @@ def load_plugin_files():
   register_plugin(Plugin('athena',start=athena_starter.start_athena))
   register_plugin(Plugin('autoscaling',start=autoscaling_starter.start_autoscaling))
   register_plugin(Plugin('azure',start=azure_starter.start_azure))
+  register_plugin(Plugin('backup',start=backup_starter.start_backup))
   register_plugin(Plugin('batch',start=batch_starter.start_batch,listener=batch_listener.UPDATE_BATCH))
   register_plugin(Plugin('cloudfront',start=cloudfront_starter.start_cloudfront))
   register_plugin(Plugin('cloudtrail',start=cloudtrail_starter.start_cloudtrail))
@@ -197,24 +199,24 @@ def load_plugin_files():
   aws_utils.patch_aws_stack()
   edge.patch_start_edge()
   patch_start_infra()
- except TvUlm as e:
-  if 'No module named' not in TvUlc(e):
+ except knpFa as e:
+  if 'No module named' not in knpFE(e):
    print('ERROR: %s'%e)
 def patch_start_infra():
  from localstack.services import infra
  try:
   from localstack_ext.utils.aws.metadata_service import start_metadata_service
- except TvUlm:
-  start_metadata_service=TvUlW
+ except knpFa:
+  start_metadata_service=knpFy
  def do_start_infra(asynchronous,apis,is_in_docker,*args,**kwargs):
   if common.in_docker():
    try:
     start_metadata_service and start_metadata_service()
-   except TvUlm:
+   except knpFa:
     pass
   enforce_before=config_ext.ENFORCE_IAM
   try:
-   config_ext.ENFORCE_IAM=TvUlx
+   config_ext.ENFORCE_IAM=knpFU
    return do_start_infra_orig(asynchronous,apis,is_in_docker,*args,**kwargs)
   finally:
    config_ext.ENFORCE_IAM=enforce_before
@@ -237,9 +239,9 @@ def _setup_logging():
  logging.getLogger('root').setLevel(logging.WARNING)
  logging.getLogger('').setLevel(logging.WARNING)
 def api_key_configured():
- return TvUlK(os.environ.get('LOCALSTACK_API_KEY'))
+ return knpFY(os.environ.get('LOCALSTACK_API_KEY'))
 def register_localstack_commands():
  if api_key_configured():
   cli.register_commands()
- return TvUlt
+ return knpFS
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
